@@ -1,14 +1,16 @@
-from .core import Pool, CatBoostError, get_catboost_bin_module, ARRAY_TYPES, STRING_TYPES, _update_params_quantize_part, _process_synonyms
+from . import _catboost
+from .core import Pool, CatBoostError, ARRAY_TYPES, STRING_TYPES, _update_params_quantize_part, _process_synonyms
 from collections import defaultdict
 from contextlib import contextmanager
 import numpy as np
 import warnings
 
-_catboost = get_catboost_bin_module()
 _eval_metric_util = _catboost._eval_metric_util
 _get_roc_curve = _catboost._get_roc_curve
 _get_confusion_matrix = _catboost._get_confusion_matrix
 _select_threshold = _catboost._select_threshold
+_NumpyAwareEncoder = _catboost._NumpyAwareEncoder
+_get_onnx_model = _catboost._get_onnx_model
 
 compute_wx_test = _catboost.compute_wx_test
 TargetStats = _catboost.TargetStats
@@ -266,11 +268,11 @@ def eval_metric(label, approx, metric, weight=None, group_id=None, subgroup_id=N
 
 
 def get_gpu_device_count():
-    return get_catboost_bin_module()._get_gpu_device_count()
+    return _catboost._get_gpu_device_count()
 
 
 def reset_trace_backend(filename):
-    get_catboost_bin_module()._reset_trace_backend(filename)
+    _catboost._reset_trace_backend(filename)
 
 
 def get_confusion_matrix(model, data, thread_count=-1):
@@ -631,3 +633,52 @@ def quantize(
     result._read(data_path, column_description, pairs, feature_names, delimiter, has_header, thread_count, params)
 
     return result
+
+
+def convert_to_onnx_object(model, export_parameters=None, **kwargs):
+    """
+    Convert given CatBoost model to ONNX-ML model.
+    Categorical Features are not supported.
+
+    Parameters
+    ----------
+    model : CatBoost trained model
+    export_parameters : dict [default=None]
+        Parameters for ONNX-ML export:
+            * onnx_graph_name : string
+                The name property of onnx Graph
+            * onnx_domain : string
+                The domain component of onnx Model
+            * onnx_model_version : int
+                The model_version component of onnx Model
+            * onnx_doc_string : string
+                The doc_string component of onnx Model
+    Returns
+    -------
+    onnx_object : ModelProto
+        The model in ONNX format
+    """
+    try:
+        import onnx
+    except ImportError as e:
+        warnings.warn("To get working onnx model you should install onnx.")
+        raise ImportError(str(e))
+
+    import json
+    if not model.is_fitted():
+        raise CatBoostError(
+            "There is no trained model to use save_model(). Use fit() to train model. Then use this method.")
+
+    for name, value in kwargs.items():
+        if name == 'target_opset' and value not in [None, 2]:
+            warnings.warn('target_opset argument is not supported. Default target_opset is 2 (ai.onnx.ml domain)')
+        elif name == 'initial_types' and value is not None:
+            warnings.warn('initial_types argument is not supported')
+
+    params_string = ""
+    if export_parameters:
+        params_string = json.dumps(export_parameters, cls=_NumpyAwareEncoder)
+
+    model_str = _get_onnx_model(model._object, params_string)
+    onnx_model = onnx.load_model_from_string(model_str)
+    return onnx_model
